<?php

// -------------------------------------------------------------------------- \\
// QuickFox kernel 2 configs interface class                                  \\
// -------------------------------------------------------------------------- \\

// Simple InUSE Check
if ( !defined('QF_STARTED') )
        die('Hacking attempt');

if ( defined('QF_KERNEL_CONFIG_LOADED') )
        die('Scripting error');

define('QF_KERNEL_CONFIG_LOADED', True);
define('QF_KERNEL_CONFIG_CACHENAME', 'GLOBAL_CONFIG');
define('QF_KERNEL_CONFIG_DEFGROUP', 'COMMON');


class QF_Configs
{
    var $values = Array();        //Config vals for groups of configs
    var $val_upd = Array();       //Updates list for saving
    var $grp_upd = Array();       //Updates list for saving
    var $need_save = false;
    var $loaded = false;

    function QF_Configs()
    {

    }

    function Load($set_empty = false)
    {
        global $QF;

        if ($this->loaded)
            return true;

        if ($set_empty)
        {
            $this->loaded = true;
            return true;
        }

        if ($chdata = $QF->Cache->Get(QF_KERNEL_CONFIG_CACHENAME))
        {
            $this->values = $chdata;
            $QF->Timer->Time_Log('Configs loaded (from global cache)');
        }
        elseif ( $sqldata = $QF->DBase->Do_Select_All('config') )
        {
            foreach ( $sqldata as $setting )
                if ( !empty($setting['name']) )
                {
                    if (empty($setting['parent']))
                        $setting['parent'] = QF_KERNEL_CONFIG_DEFGROUP;
                    if (!$setting['scalar'])
                        $setting['value'] = unserialize($setting['value']);

                    $this->values[strtolower($setting['parent'])][strtolower($setting['name'])] = $setting['value'];
                }

            $QF->Cache->Set(QF_KERNEL_CONFIG_CACHENAME, $this->values);
            $QF->Timer->Time_Log('Configs loaded (from SQL database)');
        };
        $this->loaded = true;
    }

    function Get($name, $group = false, $if_notset = null)
    {
        if (!$this->loaded)
            $this->Load();

        if (!$group)
            $group = QF_KERNEL_CONFIG_DEFGROUP;

        $group = strtolower($group);
        $name  = strtolower($name);

        if (!isset($this->values[$group]))
            return $if_notset;
        elseif (is_array($this->values[$group]) && isset($this->values[$group][$name]))
                return $this->values[$group][$name];

        return $if_notset;
    }

    function Set($name, $value, $group=false, $global=false)
    {
        if (!$this->loaded)
            $this->Load();

        if (!$group)
            $group = QF_KERNEL_CONFIG_DEFGROUP;

        $group = strtolower($group);
        $name  = strtolower($name);

        $this->values[$group][$name] = $value;

        if ($global) {
            $this->val_upd[$group][$name] = true;

            $this->need_save = true;
        }
    }

    function _Close()
    {
        global $QF;

        if (!$this->loaded)
            return true;

        if (!$this->need_save)
            return true;

        $QF->Cache->Set(QF_KERNEL_CONFIG_CACHENAME, $this->values);

        foreach ($this->val_upd as $grname => $grcont)
            if (is_array($grcont))
                foreach ($grcont as $valname => $doupd)
                    if ($doupd)
                    {
                        $value = $this->values[$grname][$valname];
                        if (is_null($value))
                            $QF->DBase->Do_Delete('config', Array( 'parent' => $grname, 'name' => $valname));
                        else
                        {
                            if (!is_scalar($value))
                            {
                                $value = serialize($value);
                                $scalar = false;
                            }
                            else
                                $scalar = true;

                            $QF->DBase->Do_Insert('config', Array( 'parent' => $grname, 'name' => $valname, 'value' => $value, 'scalar' => $scalar), true);
                        }
                    }
    }
}

?>